@@ -1,5 +1,6 @@
 from hashlib import md5
-from django_cart.cart import SingleCart, MultiCart
+from django_cart.apps import SingleCart, MultiCart
+from django_cart.utils.utils import MappedDict
 from django import template
 register = template.Library()
 
@@ -44,7 +45,7 @@ def str_md5(value:str):
 
 @register.filter()
 def get_values(data: dict, key: str):
-    return data[key]
+    return data[str(key)]
 
 @register.filter()
 def firsts(array: list, amount: int):
@@ -52,4 +53,20 @@ def firsts(array: list, amount: int):
 
 @register.filter()
 def lasts(array: list, amount: int):
-    return array[-amount:]
\ No newline at end of file
+    return array[-amount:]
+
+@register.filter()
+def model(data: dict):
+    return data[data.keys().first()]
+
+@register.filter()
+def from_model(data: dict, attr: str):
+    return data.get(str(attr), None)
+
+@register.simple_tag()
+def total(data: dict, *args):
+    data = MappedDict(data)
+    if len(args) == 0:
+        args = ("quantity", "price")
+    total = data.get_total_prod_of(*args)
+    return total
